@@ -33,7 +33,7 @@ class MIS2GCUDisplay:
     def __init__(self, port, address = 1, baudrate = 9600, exclusive = True, debug = False):
         self.address = address
         self.debug = debug
-        if isinstance(post, serial.Serial):
+        if isinstance(port, serial.Serial):
             self.port = port
         else:
             self.port = serial.Serial(port, baudrate=baudrate, bytesize=8, parity="E", stopbits=1, exclusive=exclusive)
